@@ -6,7 +6,7 @@ use utf8;
 use strict;
 use warnings;
 
-our $VERSION = '0.012'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use Carp;
 use Encode;
@@ -48,6 +48,10 @@ sub transform
     my $md = Text::Markdown->new;
     $self->_set_readable_text($md->markdown($raw));
 
+    # Ignore any errors from Text::Markdown - usually complaints about
+    # unmatched HTML tags - as it still produces a usable result.
+    $@ = "" if $@;
+
     return 1;
 }
 
@@ -57,13 +61,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Zapzi::Transformers::TextMarkdown - transform text using Markdown
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 DESCRIPTION
 
@@ -89,7 +95,7 @@ Rupert Lane <rupert@rupert-lane.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Rupert Lane.
+This software is copyright (c) 2014 by Rupert Lane.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
